==> knt_ui-1.8.2.tar.gz: lib/src/widget/popup/knt_simple_picker.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

import '../../../generated/colors.gen.dart';
import 'knt_selection_popup.dart';

const _popupDuration = Duration(milliseconds: 200);

class SimplePicker extends StatelessWidget {
  const SimplePicker({
    Key? key,
    required this.presentOption,
    this.options = const [],
    this.onPickedOption,
    this.needAnimate = false,
  }) : super(key: key);

  final Widget presentOption;
  final List<String> options;
  final Function(int, String)? onPickedOption;
  final bool needAnimate;

  @override
  Widget build(BuildContext context) {
    return GeneralPicker<String>(
      presentItem: presentOption,
      menuOptionHeight: 64.w,
      options: options,
      onConversion: (option) => option,
      onPickedOption: onPickedOption,
      animateMenuItems: needAnimate,
    );
  }
}

class GeneralPicker<T> extends StatelessWidget {
  const GeneralPicker({
    Key? key,
    required this.presentItem,
    required this.options,
    required this.onConversion,
    this.starterOption,
    this.onPickedOption,
    this.menuOptionWidth,
    this.menuOptionHeight,
    this.animateMenuItems = false,
  }) : super(key: key);

  final Widget presentItem;
  final List<T> options;
  final String Function(T) onConversion;
  final T? starterOption;
  final Function(int, T)? onPickedOption;
  final double? menuOptionWidth;
  final double? menuOptionHeight;
  final bool animateMenuItems;

  @override
  Widget build(BuildContext context) {
    return KntSelectionPopupPresenter(
      duration: _popupDuration,
      openWithTap: true,
      style: KntSelectionPopupStyle(
        bottomOffsetHeight: 8.w,
        menuOffset: 8.w,
        menuWidth: menuOptionWidth,
        menuOptionExtent: menuOptionHeight,
        needAnimate: animateMenuItems,
      ),
      options: List.generate(options.length, (index) {
        final option = options[index];
        return KntSelectionPopupOption(
          title: Padding(
            padding: EdgeInsets.symmetric(vertical: 8.w),
            child: Text(
              onConversion(option),
              style: TextStyle(
                color: ColorName.tundora,
                fontSize: 14.sp,
                fontWeight: FontWeight.w500,
                height: 16.sp / 14.sp,
              ),
            ),
          ),
          trailingIcon: option == starterOption
              ? const Icon(
                  Icons.done_rounded,
                  color: ColorName.jungleGreen,
                )
              : null,
          onPressed: () => onPickedOption?.call(index, option),
        );
      }),
      child: presentItem,
    );
  }
}

==> knt_ui-1.8.3.tar.gz: lib/src/widget/popup/knt_simple_picker.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

import '../../../generated/colors.gen.dart';
import 'knt_selection_popup.dart';

const _popupDuration = Duration(milliseconds: 200);

class KntSimplePicker extends StatelessWidget {
  const KntSimplePicker({
    Key? key,
    required this.presentOption,
    this.options = const [],
    this.onPickedOption,
    this.needAnimate = false,
  }) : super(key: key);

  final Widget presentOption;
  final List<String> options;
  final Function(int, String)? onPickedOption;
  final bool needAnimate;

  @override
  Widget build(BuildContext context) {
    return KntGeneralPicker<String>(
      presentItem: presentOption,
      menuOptionHeight: 64.w,
      options: options,
      onConversion: (option) => option,
      onPickedOption: onPickedOption,
      animateMenuItems: needAnimate,
    );
  }
}

class KntGeneralPicker<T> extends StatelessWidget {
  const KntGeneralPicker({
    Key? key,
    required this.presentItem,
    required this.options,
    required this.onConversion,
    this.starterOption,
    this.onPickedOption,
    this.menuOptionWidth,
    this.menuOptionHeight,
    this.animateMenuItems = false,
  }) : super(key: key);

  final Widget presentItem;
  final List<T> options;
  final String Function(T) onConversion;
  final T? starterOption;
  final Function(int, T)? onPickedOption;
  final double? menuOptionWidth;
  final double? menuOptionHeight;
  final bool animateMenuItems;

  @override
  Widget build(BuildContext context) {
    return KntSelectionPopupPresenter(
      duration: _popupDuration,
      openWithTap: true,
      style: KntSelectionPopupStyle(
        bottomOffsetHeight: 8.w,
        menuOffset: 8.w,
        menuWidth: menuOptionWidth,
        menuOptionExtent: menuOptionHeight,
        needAnimate: animateMenuItems,
      ),
      options: List.generate(options.length, (index) {
        final option = options[index];
        return KntSelectionPopupOption(
          title: Padding(
            padding: EdgeInsets.symmetric(vertical: 8.w),
            child: Text(
              onConversion(option),
              style: TextStyle(
                color: ColorName.tundora,
                fontSize: 14.sp,
                fontWeight: FontWeight.w500,
                height: 16.sp / 14.sp,
              ),
            ),
          ),
          trailingIcon: option == starterOption
              ? const Icon(
                  Icons.done_rounded,
                  color: ColorName.jungleGreen,
                )
              : null,
          onPressed: () => onPickedOption?.call(index, option),
        );
      }),
      child: presentItem,
    );
  }
}
